/*
 * This file is part of SplitScenarioGS, which is a GameScript for OpenTTD
 * Copyright (C) 2012  Leif Linse
 *
 * SplitScenarioGS is free software; you can redistribute it and/or modify it 
 * under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 of the License
 *
 * SplitScenarioGS is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with SplitScenarioGS; If not, see <http://www.gnu.org/licenses/> or
 * write to the Free Software Foundation, Inc., 51 Franklin Street, 
 * Fifth Floor, Boston, MA 02110-1301 USA.
 *
 */
require("version.nut");
require("version_upgrade.nut");

class FGSInfo extends GSInfo {
	function GetAuthor()		{ return "Zuu"; }
	function GetName()			{ return "SplitScenarioGS"; }
	function GetDescription() 	{ return "Split scenario GS - see manual if you want to use it in your own scenario"; }
	function GetVersion()		{ return SELF_VERSION; }
	function GetDate()			{ return "2012-06-21"; }
	function CreateInstance()	{ return "MainClass"; }
	function GetShortName()		{ return "SPLI"; }
	function GetAPIVersion()	{ return "1.2"; }
	function GetUrl()			{ return "http://www.tt-forums.net/viewtopic.php?f=60&t=61378"; }
	function MinVersionToLoad() { return ALLOW_UPGRADE? 1 : SELF_VERSION; } // don't load save games saved with an older version of the GS. Instead let the old GS load that game.
	function IsDeveloperOnly()  { return true; } 

	function GetSettings() {

		local min_prod = 345;
		local min_period = 3;
		AddSetting({name = "min_total_production", description = "Min total production to trigger land raise", easy_value = min_prod, medium_value = min_prod, hard_value = min_prod, custom_value = min_prod, flags = CONFIG_INGAME, min_value = 1, max_value = 100000});
		AddSetting({name = "min_period", description = "Min period in months during which the production have to stay above the limit", easy_value = min_period, medium_value = min_period, hard_value = min_period, custom_value = min_period, flags = CONFIG_INGAME, min_value = 0, max_value = 100000});
		AddSetting({name = "display_welcome_message", description = "Display welcome message", easy_value = 1, medium_value = 1, hard_value = 1, custom_value = 1, flags = CONFIG_INGAME | CONFIG_BOOLEAN});
		AddSetting({name = "log_level", description = "Debug: Log level (higher = print more)", easy_value = 1, medium_value = 1, hard_value = 1, custom_value = 1, flags = CONFIG_INGAME, min_value = 1, max_value = 3});
	}
}

RegisterGS(FGSInfo());
